@@ -2,18 +2,19 @@
 
 Context : SRP
 Module  : System
-Version : 1.0.0
+Version : 1.0.1
 Author  : Stefano Covino
-Date    : 24/08/2011
+Date    : 02/10/2011
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
 Usage   : to be imported
 
 History : (24/08/2011) First named version.
+        : (02/10/2011) List of Fits files function.
 """
 
 
 
-__all__ = ['ListDirTimeSorted', 'Pipe', 'Touch', 'Which']
+__all__ = ['ListDirTimeSorted', 'ListOfFitsFiles', 'Pipe', 'Touch', 'Which']
 
