@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : SRP
-Version : 1.0.33
+Version : 1.0.36
 Author  : Stefano Covino
-Date    : 11/10/2011
+Date    : 30/10/2011
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -50,6 +50,9 @@ History : (28/09/2010) First named version.
         : (29/09/2011) V. 3.10.1b3 and new filters.
         : (02/10/2011) V. 3.10.1b4, genera function for list of FITS files.
         : (11/10/2011) V. 3.10.1.
+        : (12/10/2011) V. 3.10.2b1.
+        : (23/10/2011) V. 3.10.2b2.
+        : (30/10/2011) V. 3.10.2.
 """
 
 
@@ -60,5 +63,5 @@ __all__ = ['SRPCatalogue','SRPFits','SRPFrames','SRPMath','SRPNet','SRPSpectrosc
 
 
 # Version
-__version__ = '3.10.1'
+__version__ = '3.10.2'
 
